@@ -62,7 +62,7 @@
 
 bitmap_t * bitmap_init(unsigned int size)
 {
-  bitmap_t * b = (bitmap_t*) xmalloc(sizeof(bitmap_t));
+  auto * b = (bitmap_t*) xmalloc(sizeof(bitmap_t));
   b->size = size;
   b->bitmap = (unsigned char *) xmalloc((size+7)/8);
   return b;
@@ -71,6 +71,8 @@ bitmap_t * bitmap_init(unsigned int size)
 void bitmap_free(bitmap_t* b)
 {
   if (b->bitmap)
-    xfree(b->bitmap);
+    {
+      xfree(b->bitmap);
+    }
   xfree(b);
 }
