@@ -85,48 +85,66 @@
 
 LinearMemoryAligner::LinearMemoryAligner()
 {
-  scorematrix = 0;
+  scorematrix = nullptr;
 
   cigar_alloc = 0;
-  cigar_string = 0;
+  cigar_string = nullptr;
 
   vector_alloc = 0;
-  HH = 0;
-  EE = 0;
-  XX = 0;
-  YY = 0;
+  HH = nullptr;
+  EE = nullptr;
+  XX = nullptr;
+  YY = nullptr;
 }
 
 LinearMemoryAligner::~LinearMemoryAligner()
 {
   if (cigar_string)
-    xfree(cigar_string);
+    {
+      xfree(cigar_string);
+    }
   if (HH)
-    xfree(HH);
+    {
+      xfree(HH);
+    }
   if (EE)
-    xfree(EE);
+    {
+      xfree(EE);
+    }
   if (XX)
-    xfree(XX);
+    {
+      xfree(XX);
+    }
   if (YY)
-    xfree(YY);
+    {
+      xfree(YY);
+    }
 }
 
 int64_t * LinearMemoryAligner::scorematrix_create(int64_t match, int64_t mismatch)
 {
-  int64_t * newscorematrix = (int64_t*) xmalloc(16*16*sizeof(int64_t));
+  auto * newscorematrix = (int64_t*) xmalloc(16*16*sizeof(int64_t));
 
   for(int i=0; i<16; i++)
-    for(int j=0; j<16; j++)
-      {
-        int64_t value;
-        if (ambiguous_4bit[i] || ambiguous_4bit[j])
-          value = 0;
-        else if (i == j)
-          value = match;
-        else
-          value = mismatch;
-        newscorematrix[16*i+j] = value;
-      }
+    {
+      for(int j=0; j<16; j++)
+        {
+          int64_t value;
+          if (ambiguous_4bit[i] || ambiguous_4bit[j])
+            {
+              value = 0;
+            }
+          else if (i == j)
+            {
+              value = match;
+            }
+          else
+            {
+              value = mismatch;
+            }
+          newscorematrix[16*i+j] = value;
+        }
+    }
   return newscorematrix;
 }
 
@@ -137,13 +155,21 @@ void LinearMemoryAligner::alloc_vectors(size_t x)
       vector_alloc = x;
 
       if (HH)
-        xfree(HH);
+        {
+          xfree(HH);
+        }
       if (EE)
-        xfree(EE);
+        {
+          xfree(EE);
+        }
       if (XX)
-        xfree(XX);
+        {
+          xfree(XX);
+        }
       if (YY)
-        xfree(YY);
+        {
+          xfree(YY);
+        }
 
       HH = (int64_t*) xmalloc(vector_alloc * (sizeof(int64_t)));
       EE = (int64_t*) xmalloc(vector_alloc * (sizeof(int64_t)));
@@ -168,50 +194,56 @@ void LinearMemoryAligner::cigar_reset()
 void LinearMemoryAligner::cigar_flush()
 {
   if (op_run > 0)
-  {
-    while (1)
     {
-      /* try writing string until enough memory has been allocated */
+      while (true)
+        {
+          /* try writing string until enough memory has been allocated */
 
-      int64_t rest = cigar_alloc - cigar_length;
-      int n;
-      if (op_run > 1)
-        n = snprintf(cigar_string + cigar_length,
-                     rest,
-                     "%" PRId64 "%c", op_run, op);
-      else
-        n = snprintf(cigar_string + cigar_length,
-                     rest,
-                     "%c", op);
-      if (n < 0)
-        {
-          fatal("snprintf returned a negative number.\n");
-        }
-      else if (n >= rest)
-        {
-          cigar_alloc += MAX(n - rest + 1, 64);
-          cigar_string = (char*) xrealloc(cigar_string, cigar_alloc);
-        }
-      else
-        {
-          cigar_length += n;
-          break;
+          int64_t rest = cigar_alloc - cigar_length;
+          int n;
+          if (op_run > 1)
+            {
+              n = snprintf(cigar_string + cigar_length,
+                           rest,
+                           "%" PRId64 "%c", op_run, op);
+            }
+          else
+            {
+              n = snprintf(cigar_string + cigar_length,
+                           rest,
+                           "%c", op);
+            }
+          if (n < 0)
+            {
+              fatal("snprintf returned a negative number.\n");
+            }
+          else if (n >= rest)
+            {
+              cigar_alloc += MAX(n - rest + 1, 64);
+              cigar_string = (char*) xrealloc(cigar_string, cigar_alloc);
+            }
+          else
+            {
+              cigar_length += n;
+              break;
+            }
         }
     }
-  }
 }
 
 void LinearMemoryAligner::cigar_add(char _op, int64_t run)
-  {
-    if (op == _op)
+{
+  if (op == _op)
+    {
       op_run += run;
-    else
-      {
-        cigar_flush();
-        op = _op;
-        op_run = run;
-      }
-  }
+    }
+  else
+    {
+      cigar_flush();
+      op = _op;
+      op_run = run;
+    }
+}
 
 void LinearMemoryAligner::show_matrix()
 {
@@ -219,7 +251,9 @@ void LinearMemoryAligner::show_matrix()
     {
       printf("%2d:", i);
       for(int j=0; j<16; j++)
-        printf(" %2" PRId64, scorematrix[16*i+j]);
+        {
+          printf(" %2" PRId64, scorematrix[16*i+j]);
+        }
       printf("\n");
     }
 }
@@ -279,7 +313,9 @@ void LinearMemoryAligner::diff(int64_t a_start,
       /* gap penalty for gap in B of length 1 */
 
       if (! gap_b_left)
-        Score -= b_left ? go_t_l : go_t_i;
+        {
+          Score -= b_left ? go_t_l : go_t_i;
+        }
 
       Score -= b_left ? ge_t_l : ge_t_i;
 
@@ -304,7 +340,9 @@ void LinearMemoryAligner::diff(int64_t a_start,
       /* gap penalty for gap in B of length 1 */
 
       if (! gap_b_right)
-        Score -= b_right ? go_t_r : go_t_i;
+        {
+          Score -= b_right ? go_t_r : go_t_i;
+        }
 
       Score -= b_right ? ge_t_r : ge_t_i;
 
@@ -326,14 +364,18 @@ void LinearMemoryAligner::diff(int64_t a_start,
           Score = 0;
 
           if (j > 0)
-            Score -= a_left ? go_q_l + j * ge_q_l : go_q_i + j * ge_q_i;
+            {
+              Score -= a_left ? go_q_l + j * ge_q_l : go_q_i + j * ge_q_i;
+            }
 
           Score += subst_score(a_start, b_start + j);
 
           if (j < b_len - 1)
-            Score -= a_right ?
-              go_q_r + (b_len-1-j) * ge_q_r :
-              go_q_i + (b_len-1-j) * ge_q_i;
+            {
+              Score -= a_right ?
+                go_q_r + (b_len-1-j) * ge_q_r :
+                go_q_i + (b_len-1-j) * ge_q_i;
+            }
 
           if (Score > MaxScore)
             {
@@ -355,10 +397,14 @@ void LinearMemoryAligner::diff(int64_t a_start,
       else
         {
           if (best > 0)
-            cigar_add('I', best);
+            {
+              cigar_add('I', best);
+            }
           cigar_add('M', 1);
           if (best < b_len - 1)
-            cigar_add('I', b_len - 1 - best);
+            {
+              cigar_add('I', b_len - 1 - best);
+            }
         }
     }
   else
@@ -391,8 +437,8 @@ void LinearMemoryAligner::diff(int64_t a_start,
           int64_t p = HH[0];
 
           int64_t h = - (b_left ?
-                      (gap_b_left ? 0 : go_t_l) + i * ge_t_l :
-                      (gap_b_left ? 0 : go_t_i) + i * ge_t_i);
+                         (gap_b_left ? 0 : go_t_l) + i * ge_t_l :
+                         (gap_b_left ? 0 : go_t_i) + i * ge_t_i);
 
           HH[0] = h;
           int64_t f = LONG_MIN;
@@ -401,16 +447,24 @@ void LinearMemoryAligner::diff(int64_t a_start,
             {
               f = MAX(f, h - go_q_i) - ge_q_i;
               if (b_right && (j==b_len))
-                EE[j] = MAX(EE[j], HH[j] - go_t_r) - ge_t_r;
+                {
+                  EE[j] = MAX(EE[j], HH[j] - go_t_r) - ge_t_r;
+                }
               else
-                EE[j] = MAX(EE[j], HH[j] - go_t_i) - ge_t_i;
+                {
+                  EE[j] = MAX(EE[j], HH[j] - go_t_i) - ge_t_i;
+                }
 
               h = p + subst_score(a_start + i - 1, b_start + j - 1);
 
               if (f > h)
-                h = f;
+                {
+                  h = f;
+                }
               if (EE[j] > h)
-                h = EE[j];
+                {
+                  h = EE[j];
+                }
               p = HH[j];
               HH[j] = h;
             }
@@ -439,8 +493,8 @@ void LinearMemoryAligner::diff(int64_t a_start,
           int64_t p = XX[0];
 
           int64_t h = - (b_right ?
-                      (gap_b_right ? 0 : go_t_r) + i * ge_t_r :
-                      (gap_b_right ? 0 : go_t_i) + i * ge_t_i);
+                         (gap_b_right ? 0 : go_t_r) + i * ge_t_r :
+                         (gap_b_right ? 0 : go_t_i) + i * ge_t_i);
           XX[0] = h;
           int64_t f = LONG_MIN;
 
@@ -448,16 +502,24 @@ void LinearMemoryAligner::diff(int64_t a_start,
             {
               f = MAX(f, h - go_q_i) - ge_q_i;
               if (b_left && (j==b_len))
-                YY[j] = MAX(YY[j], XX[j] - go_t_l) - ge_t_l;
+                {
+                  YY[j] = MAX(YY[j], XX[j] - go_t_l) - ge_t_l;
+                }
               else
-                YY[j] = MAX(YY[j], XX[j] - go_t_i) - ge_t_i;
+                {
+                  YY[j] = MAX(YY[j], XX[j] - go_t_i) - ge_t_i;
+                }
 
               h = p + subst_score(a_start + a_len - i, b_start + b_len - j);
 
               if (f > h)
-                h = f;
+                {
+                  h = f;
+                }
               if (YY[j] > h)
-                h = YY[j];
+                {
+                  h = YY[j];
+                }
               p = XX[j];
               XX[j] = h;
             }
@@ -493,11 +555,17 @@ void LinearMemoryAligner::diff(int64_t a_start,
         {
           int64_t g;
           if (b_left && (j==0))
-            g = go_t_l;
+            {
+              g = go_t_l;
+            }
           else if (b_right && (j==b_len))
-            g = go_t_r;
+            {
+              g = go_t_r;
+            }
           else
-            g = go_t_i;
+            {
+              g = go_t_i;
+            }
 
           int64_t Score = EE[j] + YY[b_len - j] + g;
 
@@ -623,7 +691,7 @@ char * LinearMemoryAligner::align(char * _a_seq,
   alloc_vectors(b_len+1);
 
   /* perform alignment */
-  diff(0, 0, a_len, b_len, 0, 0, true, true, true, true);
+  diff(0, 0, a_len, b_len, false, false, true, true, true, true);
 
   /* ensure entire cigar has been written */
   cigar_flush();
@@ -673,9 +741,13 @@ void LinearMemoryAligner::alignstats(char * cigar,
 
               if (chrmap_4bit[(int)(a_seq[a_pos])] &
                   chrmap_4bit[(int)(b_seq[b_pos])])
-                nwmatches++;
+                {
+                  nwmatches++;
+                }
               else
-                nwmismatches++;
+                {
+                  nwmismatches++;
+                }
 
               a_pos++;
               b_pos++;
@@ -684,11 +756,17 @@ void LinearMemoryAligner::alignstats(char * cigar,
 
         case 'I':
           if ((a_pos == 0) && (b_pos == 0))
-            g = go_q_l + run * ge_q_l;
+            {
+              g = go_q_l + run * ge_q_l;
+            }
           else if (*p == 0)
-            g = go_q_r + run * ge_q_r;
+            {
+              g = go_q_r + run * ge_q_r;
+            }
           else
-            g = go_q_i + run * ge_q_i;
+            {
+              g = go_q_i + run * ge_q_i;
+            }
           nwscore -= g;
           nwgaps++;
           nwalignmentlength += run;
@@ -697,11 +775,17 @@ void LinearMemoryAligner::alignstats(char * cigar,
 
         case 'D':
           if ((a_pos == 0) && (b_pos == 0))
-            g = go_t_l + run * ge_t_l;
+            {
+              g = go_t_l + run * ge_t_l;
+            }
           else if (*p == 0)
-            g = go_t_r + run * ge_t_r;
+            {
+              g = go_t_r + run * ge_t_r;
+            }
           else
-            g = go_t_i + run * ge_t_i;
+            {
+              g = go_t_i + run * ge_t_i;
+            }
           nwscore -= g;
           nwgaps++;
           nwalignmentlength += run;
