@@ -68,37 +68,54 @@ static struct sortinfo_size_s
 
 int sortbysize_compare(const void * a, const void * b)
 {
-  struct sortinfo_size_s * x = (struct sortinfo_size_s *) a;
-  struct sortinfo_size_s * y = (struct sortinfo_size_s *) b;
+  auto * x = (struct sortinfo_size_s *) a;
+  auto * y = (struct sortinfo_size_s *) b;
 
   /* highest abundance first, then by label, otherwise keep order */
 
   if (x->size < y->size)
-    return +1;
+    {
+      return +1;
+    }
   else if (x->size > y->size)
-    return -1;
+    {
+      return -1;
+    }
   else
     {
       int r = strcmp(db_getheader(x->seqno), db_getheader(y->seqno));
       if (r != 0)
-        return r;
+        {
+          return r;
+        }
       else
         {
           if (x->seqno < y->seqno)
-            return -1;
+            {
+              return -1;
+            }
           else if (x->seqno > y->seqno)
-            return +1;
+            {
+              return +1;
+            }
           else
-            return 0;
+            {
+              return 0;
+            }
         }
     }
 }
 
 void sortbysize()
 {
+  if (!opt_output)
+    fatal("FASTA output file for sortbysize must be specified with --output");
+
   FILE * fp_output = fopen_output(opt_output);
   if (!fp_output)
-    fatal("Unable to open sortbysize output file for writing");
+    {
+      fatal("Unable to open sortbysize output file for writing");
+    }
 
   db_read(opt_sortbysize, 0);
 
@@ -138,17 +155,25 @@ void sortbysize()
   if (passed > 0)
     {
       if (passed % 2)
-        median = sortinfo[(passed-1)/2].size;
+        {
+          median = sortinfo[(passed-1)/2].size;
+        }
       else
-        median = (sortinfo[(passed/2)-1].size +
-                  sortinfo[passed/2].size) / 2.0;
+        {
+          median = (sortinfo[(passed/2)-1].size +
+                    sortinfo[passed/2].size) / 2.0;
+        }
     }
 
   if (! opt_quiet)
-    fprintf(stderr, "Median abundance: %.0f\n", median);
+    {
+      fprintf(stderr, "Median abundance: %.0f\n", median);
+    }
 
   if (opt_log)
-    fprintf(fp_log, "Median abundance: %.0f\n", median);
+    {
+      fprintf(fp_log, "Median abundance: %.0f\n", median);
+    }
 
   show_rusage();
 
